@@ -18,10 +18,10 @@
 
 using namespace EventViews;
 
-class Q_DECL_HIDDEN TimeScaleConfigDialog::Private
+class EventViews::TimeScaleConfigDialogPrivate
 {
 public:
-    Private(TimeScaleConfigDialog *parent, const PrefsPtr &preferences)
+    TimeScaleConfigDialogPrivate(TimeScaleConfigDialog *parent, const PrefsPtr &preferences)
         : q(parent)
         , mPreferences(preferences)
     {
@@ -44,7 +44,7 @@ static QString tzWithUTC(const QByteArray &zoneId)
 
 TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this, preferences))
+    , d(new TimeScaleConfigDialogPrivate(this, preferences))
 {
     setWindowTitle(i18nc("@title:window", "Timezone"));
     auto mainLayout = new QVBoxLayout(this);
@@ -67,7 +67,8 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
     shownTimeZones += d->mPreferences->timeScaleTimezones();
     shownTimeZones.removeDuplicates();
 
-    QVector<TimeZoneNamePair> availList, selList;
+    QList<TimeZoneNamePair> availList;
+    QList<TimeZoneNamePair> selList;
     const auto zoneIds = QTimeZone::availableTimeZoneIds();
     for (const auto &zoneId : std::as_const(zoneIds)) {
         // do not list timezones already shown
@@ -106,10 +107,7 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
     slotUpdateButton();
 }
 
-TimeScaleConfigDialog::~TimeScaleConfigDialog()
-{
-    delete d;
-}
+TimeScaleConfigDialog::~TimeScaleConfigDialog() = default;
 
 void TimeScaleConfigDialog::slotUpdateButton()
 {
@@ -178,3 +176,5 @@ QStringList TimeScaleConfigDialog::zones() const
     }
     return list;
 }
+
+#include "moc_timescaleconfigdialog.cpp"
